changeset 356:b1b476305c6e

v0.5.10.12: Fixes.
author Matti Hamalainen <ccr@tnsp.org>
date Thu, 23 Mar 2006 20:14:06 +0000
parents 32c884e80dd3
children 95b3fddef362
files ggrtf-magical.tf ggrtf.tf
diffstat 2 files changed, 7 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/ggrtf-magical.tf	Thu Mar 23 17:12:22 2006 +0000
+++ b/ggrtf-magical.tf	Thu Mar 23 20:14:06 2006 +0000
@@ -268,6 +268,9 @@
 /def -i -F -p9999 -ag -mregexp -t"^You watch with selfpride as your ([a-z ]+) hits (.+)\.$" gspell_hit1 =\
 	/test prspellhit({P1},{P2})
 
+/def -i -F -p9999 -ag -mregexp -t"^You crush (.+)\'s mind with your psychic attack!$" gspell_hit2 =\
+	/test prspellhit("psychic crush",{P1})
+
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Damage criticality
--- a/ggrtf.tf	Thu Mar 23 17:12:22 2006 +0000
+++ b/ggrtf.tf	Thu Mar 23 20:14:06 2006 +0000
@@ -1,8 +1,8 @@
 ;;
 ;; GgrTF v0.5.10.11-svn - TinyFugue script for BatMUD
 ;; (C) Copyright 2004-2006 Matti Hämäläinen (Ggr Pupunen)
 ;;
-/set ggrtf_ver=0.5.10.11-svn
+/set ggrtf_ver=0.5.10.12-svn
 ;;
 ;; This triggerset is Free Software distributed under
 ;; GNU General Public License version 2.
@@ -1248,7 +1248,8 @@
 /prdefprot -i"levi"	-n"Levi"	-l"Levitation" -u"You slowly rise from the ground and start levitating." -d"You decide that you have levitated enough and slowly descend to the ground."
 /prdefprot -i"forcesh"	-n"FSh"		-l"Force Shield" -r -A"^([A-Z][a-z]+ is surrounded by blue waves as you hear|You tap the power of the blue star with) the words \'thoiiiiiisss huuuiahashn\'$" -u"^(You form a psionic shield of force around your body|[A-Z][a-z]+ forms a shield of force around you)\.$" -d"^Your armour feels thinner.$"
 /prdefprot -i"psish"	-n"PsiSh"	-l"Psionic Shield" -u"Psionic waves surge through your body and mind!" -d"The psionic shield vanishes."
-/prdefprot -i"minddev"	-n"MindDev"	-l"Mind Development" -s -u"You feel your mind developing." -d"Your brain suddenly seems smaller."
+/prdefprot -i"minddev"	-n"MDev"	-l"Mind Development" -s -u"You feel your mind developing." -d"Your brain suddenly seems smaller."
+/prdefprot -i"transs"	-n"TSelf"	-l"Transmute Self" -A" \'nihenuak assaam no nek orrek\'$" -u"There is a puff of logic!" -d"You feel like the illusion around you lifted."
 
 ;; ---- Druid ----
 /prdefprot -i"flexsh"	-n"FlexSh"	-l"Flex Shield" -u"You sense a flex shield covering your body like a second skin." -d"Your flex shield wobbles, PINGs and vanishes."
@@ -1,8 +1,8 @@
 ;;
-;; GgrTF v0.5.10.11-svn - TinyFugue script for BatMUD
+;; GgrTF v0.5.10.12-svn - TinyFugue script for BatMUD
 ;; (C) Copyright 2004-2006 Matti Hämäläinen (Ggr Pupunen)
 ;;